==> matrix_api_lite-0.4.1.tar.gz: lib/src/model/matrix_keys.dart <==
/* MIT License
* 
* Copyright (C) 2019, 2020, 2021 Famedly GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/

import '../utils/map_copy_extension.dart';

abstract class MatrixSignableKey {
  String userId;

  String? get identifier;

  Map<String, String> keys;
  Map<String, Map<String, String>>? signatures;
  Map<String, dynamic>? unsigned;

  MatrixSignableKey(this.userId, this.keys, this.signatures, {this.unsigned});

  // This object is used for signing so we need the raw json too
  Map<String, dynamic>? _json;

  MatrixSignableKey.fromJson(Map<String, dynamic> json)
      : _json = json,
        userId = json['user_id'],
        keys = Map<String, String>.from(json['keys']),
        // we need to manually copy to ensure that our map is Map<String, Map<String, String>>
        signatures = json['signatures'] is Map
            ? Map<String, Map<String, String>>.from((json['signatures'] as Map)
                .map((k, v) => MapEntry(k, Map<String, String>.from(v))))
            : null,
        unsigned = (json['unsigned'] as Map<String, dynamic>?)?.copy();

  Map<String, dynamic> toJson() {
    final data = _json ?? <String, dynamic>{};
    data['user_id'] = userId;
    data['keys'] = keys;

    if (signatures != null) {
      data['signatures'] = signatures;
    }
    if (unsigned != null) {
      data['unsigned'] = unsigned;
    }
    return data;
  }
}

class MatrixCrossSigningKey extends MatrixSignableKey {
  List<String> usage;

  String? get publicKey => identifier;

  MatrixCrossSigningKey(
    String userId,
    this.usage,
    Map<String, String> keys,
    Map<String, Map<String, String>> signatures, {
    Map<String, dynamic>? unsigned,
  }) : super(userId, keys, signatures, unsigned: unsigned);

  @override
  String? get identifier => keys.values.first;

  @override
  MatrixCrossSigningKey.fromJson(Map<String, dynamic> json)
      : usage = List<String>.from(json['usage']),
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    final data = super.toJson();
    data['usage'] = usage;
    return data;
  }
}

class MatrixDeviceKeys extends MatrixSignableKey {
  String deviceId;
  List<String> algorithms;

  String? get deviceDisplayName =>
      unsigned != null ? unsigned!['device_display_name'] : null;

  MatrixDeviceKeys(
    String userId,
    this.deviceId,
    this.algorithms,
    Map<String, String> keys,
    Map<String, Map<String, String>> signatures, {
    Map<String, dynamic>? unsigned,
  }) : super(userId, keys, signatures, unsigned: unsigned);

  @override
  String? get identifier => deviceId;

  @override
  MatrixDeviceKeys.fromJson(Map<String, dynamic> json)
      : algorithms = json['algorithms'].cast<String>(),
        deviceId = json['device_id'],
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    final data = super.toJson();
    data['device_id'] = deviceId;
    data['algorithms'] = algorithms;
    return data;
  }
}

==> matrix_api_lite-1.1.4.tar.gz: lib/src/model/matrix_keys.dart <==
/* MIT License
* 
* Copyright (C) 2019, 2020, 2021 Famedly GmbH
* 
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
* 
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
* 
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*/

import 'package:matrix_api_lite/matrix_api_lite.dart';

abstract class MatrixSignableKey {
  String userId;

  String? get identifier;

  Map<String, String> keys;
  Map<String, Map<String, String>>? signatures;
  Map<String, dynamic>? unsigned;

  MatrixSignableKey(this.userId, this.keys, this.signatures, {this.unsigned});

  // This object is used for signing so we need the raw json too
  Map<String, dynamic>? _json;

  MatrixSignableKey.fromJson(Map<String, dynamic> json)
      : _json = json,
        userId = json['user_id'] as String,
        keys = Map<String, String>.from(json['keys'] as Map<String, dynamic>),
        // we need to manually copy to ensure that our map is Map<String, Map<String, String>>
        signatures = json.tryGetMap<String, Map<String, String>>('signatures'),
        unsigned = json.tryGetMap<String, dynamic>('unsigned');

  Map<String, dynamic> toJson() {
    final data = _json ?? <String, dynamic>{};
    data['user_id'] = userId;
    data['keys'] = keys;

    if (signatures != null) {
      data['signatures'] = signatures;
    }
    if (unsigned != null) {
      data['unsigned'] = unsigned;
    }
    return data;
  }
}

class MatrixCrossSigningKey extends MatrixSignableKey {
  List<String> usage;

  String? get publicKey => identifier;

  MatrixCrossSigningKey(
    String userId,
    this.usage,
    Map<String, String> keys,
    Map<String, Map<String, String>> signatures, {
    Map<String, dynamic>? unsigned,
  }) : super(userId, keys, signatures, unsigned: unsigned);

  @override
  String? get identifier => keys.values.first;

  @override
  MatrixCrossSigningKey.fromJson(Map<String, dynamic> json)
      : usage = json.tryGetList<String>('usage') ?? [],
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    final data = super.toJson();
    data['usage'] = usage;
    return data;
  }
}

class MatrixDeviceKeys extends MatrixSignableKey {
  String deviceId;
  List<String> algorithms;

  String? get deviceDisplayName =>
      unsigned?.tryGet<String>('device_display_name');

  MatrixDeviceKeys(
    String userId,
    this.deviceId,
    this.algorithms,
    Map<String, String> keys,
    Map<String, Map<String, String>> signatures, {
    Map<String, dynamic>? unsigned,
  }) : super(userId, keys, signatures, unsigned: unsigned);

  @override
  String? get identifier => deviceId;

  @override
  MatrixDeviceKeys.fromJson(Map<String, dynamic> json)
      : algorithms = json.tryGetList<String>('algorithms') ?? [],
        deviceId = json['device_id'] as String,
        super.fromJson(json);

  @override
  Map<String, dynamic> toJson() {
    final data = super.toJson();
    data['device_id'] = deviceId;
    data['algorithms'] = algorithms;
    return data;
  }
}
